Documentation
¶
Index ¶
- Variables
- func NewPathMapperServerHandle(o PathMapperServer) dcerpc.ServerHandle
- func PathMapperServerHandle(ctx context.Context, o PathMapperServer, opNum int, r ndr.Reader) (dcerpc.Operation, error)
- func RegisterPathMapperServer(conn dcerpc.Conn, o PathMapperServer, opts ...dcerpc.Option)
- type GetSharePathsForLocalPathRequest
- type GetSharePathsForLocalPathResponse
- type PathMapperClient
- type PathMapperServer
Constants ¶
This section is empty.
Variables ¶
var ( // IFsrmPathMapper interface identifier 6f4dbfff-6920-4821-a6c3-b7e94c1fd60c PathMapperIID = &dcom.IID{Data1: 0x6f4dbfff, Data2: 0x6920, Data3: 0x4821, Data4: []byte{0xa6, 0xc3, 0xb7, 0xe9, 0x4c, 0x1f, 0xd6, 0x0c}} // Syntax UUID PathMapperSyntaxUUID = &uuid.UUID{TimeLow: 0x6f4dbfff, TimeMid: 0x6920, TimeHiAndVersion: 0x4821, ClockSeqHiAndReserved: 0xa6, ClockSeqLow: 0xc3, Node: [6]uint8{0xb7, 0xe9, 0x4c, 0x1f, 0xd6, 0xc}} // Syntax ID PathMapperSyntaxV0_0 = &dcerpc.SyntaxID{IfUUID: PathMapperSyntaxUUID, IfVersionMajor: 0, IfVersionMinor: 0} )
var (
// import guard
GoPackage = "dcom/fsrm"
)
Functions ¶
func NewPathMapperServerHandle ¶
func NewPathMapperServerHandle(o PathMapperServer) dcerpc.ServerHandle
func PathMapperServerHandle ¶
func RegisterPathMapperServer ¶
func RegisterPathMapperServer(conn dcerpc.Conn, o PathMapperServer, opts ...dcerpc.Option)
Types ¶
type GetSharePathsForLocalPathRequest ¶
type GetSharePathsForLocalPathRequest struct {
This *dcom.ORPCThis `idl:"name:This" json:"this"`
LocalPath *oaut.String `idl:"name:localPath" json:"local_path"`
}
GetSharePathsForLocalPathRequest structure represents the GetSharePathsForLocalPath operation request
func (*GetSharePathsForLocalPathRequest) MarshalNDR ¶
func (*GetSharePathsForLocalPathRequest) UnmarshalNDR ¶
type GetSharePathsForLocalPathResponse ¶
type GetSharePathsForLocalPathResponse struct {
That *dcom.ORPCThat `idl:"name:That" json:"that"`
// share paths that point to the specified path.
SharePaths *oaut.SafeArray `idl:"name:sharePaths" json:"share_paths"`
Return int32 `idl:"name:Return" json:"return"`
}
GetSharePathsForLocalPathResponse structure represents the GetSharePathsForLocalPath operation response
func (*GetSharePathsForLocalPathResponse) MarshalNDR ¶
func (*GetSharePathsForLocalPathResponse) UnmarshalNDR ¶
type PathMapperClient ¶
type PathMapperClient interface {
// IDispatch retrieval method.
Dispatch() idispatch.DispatchClient
// to the specified local path.
//
// Return Values: The method MUST return zero on success, or a nonzero error code on
// failure.
//
// +--------------------------------+----------------------------------------------------------------------------------+
// | RETURN | |
// | VALUE/CODE | DESCRIPTION |
// | | |
// +--------------------------------+----------------------------------------------------------------------------------+
// +--------------------------------+----------------------------------------------------------------------------------+
// | 0x80045306 FSRM_E_INVALID_PATH | The local path to return network shares does not exist or exceeds the maximum |
// | | length of 260 characters. |
// +--------------------------------+----------------------------------------------------------------------------------+
// | 0x80070057 E_INVALIDARG | This code is returned for the following reasons: The localPath parameter is |
// | | empty or NULL. The sharePaths parameter is NULL. |
// +--------------------------------+----------------------------------------------------------------------------------+
GetSharePathsForLocalPath(context.Context, *GetSharePathsForLocalPathRequest, ...dcerpc.CallOption) (*GetSharePathsForLocalPathResponse, error)
// AlterContext alters the client context.
AlterContext(context.Context, ...dcerpc.Option) error
// IPID sets the object interface identifier.
IPID(context.Context, *dcom.IPID) PathMapperClient
}
IFsrmPathMapper interface.
func NewPathMapperClient ¶
type PathMapperServer ¶
type PathMapperServer interface {
// IDispatch base class.
idispatch.DispatchServer
// to the specified local path.
//
// Return Values: The method MUST return zero on success, or a nonzero error code on
// failure.
//
// +--------------------------------+----------------------------------------------------------------------------------+
// | RETURN | |
// | VALUE/CODE | DESCRIPTION |
// | | |
// +--------------------------------+----------------------------------------------------------------------------------+
// +--------------------------------+----------------------------------------------------------------------------------+
// | 0x80045306 FSRM_E_INVALID_PATH | The local path to return network shares does not exist or exceeds the maximum |
// | | length of 260 characters. |
// +--------------------------------+----------------------------------------------------------------------------------+
// | 0x80070057 E_INVALIDARG | This code is returned for the following reasons: The localPath parameter is |
// | | empty or NULL. The sharePaths parameter is NULL. |
// +--------------------------------+----------------------------------------------------------------------------------+
GetSharePathsForLocalPath(context.Context, *GetSharePathsForLocalPathRequest) (*GetSharePathsForLocalPathResponse, error)
}
IFsrmPathMapper server interface.
Click to show internal directories.
Click to hide internal directories.