Documentation
¶
Index ¶
- Variables
- func Dscomm2ServerHandle(ctx context.Context, o Dscomm2Server, opNum int, r ndr.Reader) (dcerpc.Operation, error)
- func NewDscomm2ServerHandle(o Dscomm2Server) dcerpc.ServerHandle
- func RegisterDscomm2Server(conn dcerpc.Conn, o Dscomm2Server, opts ...dcerpc.Option)
- type BeginDeleteNotificationRequest
- type BeginDeleteNotificationResponse
- type Dscomm2Client
- type Dscomm2Server
- type EndDeleteNotificationRequest
- type EndDeleteNotificationResponse
- type GetComputerSitesRequest
- type GetComputerSitesResponse
- type GetGCListInDomainRequest
- type GetGCListInDomainResponse
- type GetPropertiesExRequest
- type GetPropertiesExResponse
- type GetPropertiesGUIDExRequest
- type GetPropertiesGUIDExResponse
- type IsServerGCRequest
- type IsServerGCResponse
- type NotifyDeleteRequest
- type NotifyDeleteResponse
Constants ¶
This section is empty.
Variables ¶
var ( // Syntax UUID Dscomm2SyntaxUUID = &uuid.UUID{TimeLow: 0x708cca10, TimeMid: 0x9569, TimeHiAndVersion: 0x11d1, ClockSeqHiAndReserved: 0xb2, ClockSeqLow: 0xa5, Node: [6]uint8{0x0, 0x60, 0x97, 0x7d, 0x81, 0x18}} // Syntax ID Dscomm2SyntaxV1_0 = &dcerpc.SyntaxID{IfUUID: Dscomm2SyntaxUUID, IfVersionMajor: 1, IfVersionMinor: 0} )
var (
// import guard
GoPackage = "mqds"
)
Functions ¶
func Dscomm2ServerHandle ¶
func NewDscomm2ServerHandle ¶
func NewDscomm2ServerHandle(o Dscomm2Server) dcerpc.ServerHandle
func RegisterDscomm2Server ¶
func RegisterDscomm2Server(conn dcerpc.Conn, o Dscomm2Server, opts ...dcerpc.Option)
Types ¶
type BeginDeleteNotificationRequest ¶
type BeginDeleteNotificationRequest struct {
// pwcsPathName: MUST be set by the client to a pointer to a NULL-terminated 16-bit
// Unicode string that contains the directory service pathname, as specified in section
// 2.2.9, for an object of type MQDS_MACHINE or MQDS_QUEUE.<157>
PathName string `idl:"name:pwcsPathName;string" json:"path_name"`
// phServerAuth: A PCONTEXT_HANDLE_SERVER_AUTH_TYPE RPC context handle acquired from
// the pphServerAuth parameter in a previous call to S_DSValidateServer. The server
// MUST use this parameter as a key to locate the GSS security context used to compute
// the signature returned in pbServerSignature. See section 3.1.4.2.
ServerAuth *dscomm.ServerAuthType `idl:"name:phServerAuth" json:"server_auth"`
}
BeginDeleteNotificationRequest structure represents the S_DSBeginDeleteNotification operation request
func (*BeginDeleteNotificationRequest) MarshalNDR ¶
func (*BeginDeleteNotificationRequest) UnmarshalNDR ¶
type BeginDeleteNotificationResponse ¶
type BeginDeleteNotificationResponse struct {
// pHandle: MUST be set by the server to a pointer to a unique RPC context_handle
// representing the delete notification. This handle is used by the client in subsequent
// calls to S_DSNotifyDelete.
Handle *dscomm.DeleteType `idl:"name:pHandle" json:"handle"`
// Return: The S_DSBeginDeleteNotification return value.
Return int32 `idl:"name:Return" json:"return"`
}
BeginDeleteNotificationResponse structure represents the S_DSBeginDeleteNotification operation response
func (*BeginDeleteNotificationResponse) MarshalNDR ¶
func (*BeginDeleteNotificationResponse) UnmarshalNDR ¶
type Dscomm2Client ¶
type Dscomm2Client interface {
// The S_DSGetComputerSites method returns the site identifier for every site of which
// the specified computer is a member.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC protocol, as specified in [MS-RPCE].
GetComputerSites(context.Context, *GetComputerSitesRequest, ...dcerpc.CallOption) (*GetComputerSitesResponse, error)
// The S_DSGetPropsEx method returns the properties associated with the object specified
// by a directory service pathname. This method differs from S_DSGetProps (section 3.1.4.7)
// in that it supports a restricted set of properties that pertain only to queue or
// machine object security.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC protocol, as specified in [MS-RPCE].
GetPropertiesEx(context.Context, *GetPropertiesExRequest, ...dcerpc.CallOption) (*GetPropertiesExResponse, error)
// This method returns the properties for the object specified by object identifier.
// This method differs from S_DSGetPropsGuid in that it supports a restricted set of
// properties that pertain only to queue or machine object security.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC extension protocol, as specified in [MS-RPCE].
GetPropertiesGUIDEx(context.Context, *GetPropertiesGUIDExRequest, ...dcerpc.CallOption) (*GetPropertiesGUIDExResponse, error)
// The S_DSBeginDeleteNotification method begins a delete notification and returns an
// RPC context handle associated with the delete notification.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.<158>
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC protocol, as specified in [MS-RPCE].
BeginDeleteNotification(context.Context, *BeginDeleteNotificationRequest, ...dcerpc.CallOption) (*BeginDeleteNotificationResponse, error)
// This method instructs the server to notify the computer that owns the deleted object
// about the deletion.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC extension protocol, as specified in [MS-RPCE].
NotifyDelete(context.Context, *NotifyDeleteRequest, ...dcerpc.CallOption) (*NotifyDeleteResponse, error)
// The S_DSEndDeleteNotification method closes the RPC context handle acquired from
// a previous call to S_DSBeginDeleteNotification.
//
// Return Values: None.
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC protocol, as specified in [MS-RPCE].
EndDeleteNotification(context.Context, *EndDeleteNotificationRequest, ...dcerpc.CallOption) (*EndDeleteNotificationResponse, error)
// This method returns a value that indicates if that server is a Global Catalog Server.
//
// Return Values: This method returns TRUE (0x00000001) if the Directory Service server
// is also a Global Catalog Server; otherwise, it returns FALSE (0x00000000).
//
// TRUE (0x00000001)
//
// FALSE (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC extension protocol, as specified in [MS-RPCE].
IsServerGC(context.Context, *IsServerGCRequest, ...dcerpc.CallOption) (*IsServerGCResponse, error)
// The S_DSGetGCListInDomain method returns the list of Global Catalog Servers in the
// specified domain.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC protocol, Remote Procedure Call Protocol Extensions, as specified in [MS-RPCE].
GetGCListInDomain(context.Context, *GetGCListInDomainRequest, ...dcerpc.CallOption) (*GetGCListInDomainResponse, error)
// AlterContext alters the client context.
AlterContext(context.Context, ...dcerpc.Option) error
}
dscomm2 interface.
func NewDscomm2Client ¶
type Dscomm2Server ¶
type Dscomm2Server interface {
// The S_DSGetComputerSites method returns the site identifier for every site of which
// the specified computer is a member.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC protocol, as specified in [MS-RPCE].
GetComputerSites(context.Context, *GetComputerSitesRequest) (*GetComputerSitesResponse, error)
// The S_DSGetPropsEx method returns the properties associated with the object specified
// by a directory service pathname. This method differs from S_DSGetProps (section 3.1.4.7)
// in that it supports a restricted set of properties that pertain only to queue or
// machine object security.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC protocol, as specified in [MS-RPCE].
GetPropertiesEx(context.Context, *GetPropertiesExRequest) (*GetPropertiesExResponse, error)
// This method returns the properties for the object specified by object identifier.
// This method differs from S_DSGetPropsGuid in that it supports a restricted set of
// properties that pertain only to queue or machine object security.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC extension protocol, as specified in [MS-RPCE].
GetPropertiesGUIDEx(context.Context, *GetPropertiesGUIDExRequest) (*GetPropertiesGUIDExResponse, error)
// The S_DSBeginDeleteNotification method begins a delete notification and returns an
// RPC context handle associated with the delete notification.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.<158>
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC protocol, as specified in [MS-RPCE].
BeginDeleteNotification(context.Context, *BeginDeleteNotificationRequest) (*BeginDeleteNotificationResponse, error)
// This method instructs the server to notify the computer that owns the deleted object
// about the deletion.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC extension protocol, as specified in [MS-RPCE].
NotifyDelete(context.Context, *NotifyDeleteRequest) (*NotifyDeleteResponse, error)
// The S_DSEndDeleteNotification method closes the RPC context handle acquired from
// a previous call to S_DSBeginDeleteNotification.
//
// Return Values: None.
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC protocol, as specified in [MS-RPCE].
EndDeleteNotification(context.Context, *EndDeleteNotificationRequest) (*EndDeleteNotificationResponse, error)
// This method returns a value that indicates if that server is a Global Catalog Server.
//
// Return Values: This method returns TRUE (0x00000001) if the Directory Service server
// is also a Global Catalog Server; otherwise, it returns FALSE (0x00000000).
//
// TRUE (0x00000001)
//
// FALSE (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC extension protocol, as specified in [MS-RPCE].
IsServerGC(context.Context, *IsServerGCRequest) (*IsServerGCResponse, error)
// The S_DSGetGCListInDomain method returns the list of Global Catalog Servers in the
// specified domain.
//
// Return Values: If the method succeeds, the return value is MQ_OK (0x00000000).
// If the method fails, the return value is an implementation-specific error code.
//
// MQ_OK (0x00000000)
//
// Exceptions Thrown: No exceptions are thrown beyond those thrown by the underlying
// RPC protocol, Remote Procedure Call Protocol Extensions, as specified in [MS-RPCE].
GetGCListInDomain(context.Context, *GetGCListInDomainRequest) (*GetGCListInDomainResponse, error)
}
dscomm2 server interface.
type EndDeleteNotificationRequest ¶
type EndDeleteNotificationRequest struct {
// pHandle: MUST be set by the client to a pointer to an RPC context_handle returned
// by a previous call to S_DSBeginDeleteNotification. The RPC context handle MUST NOT
// have been used in a previous call to S_DSEndDeleteNotification. The server MUST set
// this parameter to NULL.
Handle *dscomm.DeleteType `idl:"name:pHandle" json:"handle"`
}
EndDeleteNotificationRequest structure represents the S_DSEndDeleteNotification operation request
func (*EndDeleteNotificationRequest) MarshalNDR ¶
func (*EndDeleteNotificationRequest) UnmarshalNDR ¶
type EndDeleteNotificationResponse ¶
type EndDeleteNotificationResponse struct {
// pHandle: MUST be set by the client to a pointer to an RPC context_handle returned
// by a previous call to S_DSBeginDeleteNotification. The RPC context handle MUST NOT
// have been used in a previous call to S_DSEndDeleteNotification. The server MUST set
// this parameter to NULL.
Handle *dscomm.DeleteType `idl:"name:pHandle" json:"handle"`
}
EndDeleteNotificationResponse structure represents the S_DSEndDeleteNotification operation response
func (*EndDeleteNotificationResponse) MarshalNDR ¶
func (*EndDeleteNotificationResponse) UnmarshalNDR ¶
type GetComputerSitesRequest ¶
type GetComputerSitesRequest struct {
// pwcsPathName: MUST be set by the client to a pointer to a NULL-terminated 16-bit
// Unicode string that contains the directory service pathname, as specified in section
// 2.2.9, of the object in the Directory Service. The pathname MUST be the pathname
// of an object of type MQDS_MACHINE.<154>
PathName string `idl:"name:pwcsPathName;string;pointer:unique" json:"path_name"`
// phServerAuth: A PCONTEXT_HANDLE_SERVER_AUTH_TYPE RPC context handle acquired from
// the pphServerAuth parameter in a previous call to S_DSValidateServer. The server
// MUST use this parameter as a key to locate the GSS security context used to compute
// the signature returned in pbServerSignature. See section 3.1.4.2.
ServerAuth *dscomm.ServerAuthType `idl:"name:phServerAuth" json:"server_auth"`
// pdwServerSignatureSize: Contains the maximum length of the server signature in bytes
// to return.
ServerSignatureSize uint32 `idl:"name:pdwServerSignatureSize" json:"server_signature_size"`
}
GetComputerSitesRequest structure represents the S_DSGetComputerSites operation request
func (*GetComputerSitesRequest) MarshalNDR ¶
func (*GetComputerSitesRequest) UnmarshalNDR ¶
type GetComputerSitesResponse ¶
type GetComputerSitesResponse struct {
// pdwNumberOfSites: Number of site identifiers returned in the ppguidSites parameter.
NumberOfSites uint32 `idl:"name:pdwNumberOfSites" json:"number_of_sites"`
// ppguidSites: An array of pointers to the GUID site identifiers of the sites of which
// the computer is a member. Each GUID referenced by the array MUST be the site identifier
// for a site that the machine object specified by pwcsPathName is a member of. These
// are obtained from the PROPID_QM_SITE_IDS property of the MQDS_MACHINE object. The
// array MUST contain the site identifier for every site to which the object specified
// by pwcsPathName is a member.
Sites []*dtyp.GUID `idl:"name:ppguidSites;size_is:(, pdwNumberOfSites);length_is:(, pdwNumberOfSites)" json:"sites"`
// pbServerSignature: A buffer that contains a signed hash over the array of site GUIDs
// returned in ppguidSites.
ServerSignature []byte `idl:"name:pbServerSignature;size_is:(pdwServerSignatureSize)" json:"server_signature"`
// pdwServerSignatureSize: Contains the maximum length of the server signature in bytes
// to return.
ServerSignatureSize uint32 `idl:"name:pdwServerSignatureSize" json:"server_signature_size"`
// Return: The S_DSGetComputerSites return value.
Return int32 `idl:"name:Return" json:"return"`
}
GetComputerSitesResponse structure represents the S_DSGetComputerSites operation response
func (*GetComputerSitesResponse) MarshalNDR ¶
func (*GetComputerSitesResponse) UnmarshalNDR ¶
type GetGCListInDomainRequest ¶
type GetGCListInDomainRequest struct {
// lpwszComputerName: MUST be set by the client to NULL. The server will validate
// the NULL setting.
ComputerName string `idl:"name:lpwszComputerName;string;pointer:ptr" json:"computer_name"`
// lpwszDomainName: MUST be set by the client to the domain name of the domain to
// query.
DomainName string `idl:"name:lpwszDomainName;string;pointer:ptr" json:"domain_name"`
// phServerAuth: A PCONTEXT_HANDLE_SERVER_AUTH_TYPE RPC context handle acquired from
// the pphServerAuth parameter in a previous call to S_DSValidateServer. The server
// MUST use this parameter as a key to locate the GSS security context used to compute
// the signature returned in pbServerSignature.
ServerAuth *dscomm.ServerAuthType `idl:"name:phServerAuth" json:"server_auth"`
// pdwServerSignatureSize: MUST be set by the client to point to a DWORD that contains
// the maximum size in bytes of the server signature to return, and MUST be set by the
// server to contain the actual size in bytes of the server signature on output.
ServerSignatureSize uint32 `idl:"name:pdwServerSignatureSize" json:"server_signature_size"`
}
GetGCListInDomainRequest structure represents the S_DSGetGCListInDomain operation request
func (*GetGCListInDomainRequest) MarshalNDR ¶
func (*GetGCListInDomainRequest) UnmarshalNDR ¶
type GetGCListInDomainResponse ¶
type GetGCListInDomainResponse struct {
// lplpwszGCList: MUST be set by the server to the list of Global Catalog Servers.
// The format of the list is a Server Specification List String.
GCList string `idl:"name:lplpwszGCList;string" json:"gc_list"`
// pbServerSignature: MUST be set by the server to a buffer that contains a signed
// hash over the returned list of Global Catalog Servers (lplpwszGCList) calculated
// by using the MD5 algorithm (as specified in [RFC1321]) and the GSS security context,
// as specified by the following pseudocode.
ServerSignature []byte `idl:"name:pbServerSignature;size_is:(pdwServerSignatureSize)" json:"server_signature"`
// pdwServerSignatureSize: MUST be set by the client to point to a DWORD that contains
// the maximum size in bytes of the server signature to return, and MUST be set by the
// server to contain the actual size in bytes of the server signature on output.
ServerSignatureSize uint32 `idl:"name:pdwServerSignatureSize" json:"server_signature_size"`
// Return: The S_DSGetGCListInDomain return value.
Return int32 `idl:"name:Return" json:"return"`
}
GetGCListInDomainResponse structure represents the S_DSGetGCListInDomain operation response
func (*GetGCListInDomainResponse) MarshalNDR ¶
func (*GetGCListInDomainResponse) UnmarshalNDR ¶
type GetPropertiesExRequest ¶
type GetPropertiesExRequest struct {
// dwObjectType: Specifies the type of object for which properties are to be retrieved.
// MUST be set to one of the object types, as specified in section 2.2.8.
ObjectType uint32 `idl:"name:dwObjectType" json:"object_type"`
// pwcsPathName: MUST be set by the client to a pointer to a NULL-terminated 16-bit
// Unicode string that contains the directory service pathname, as specified in section
// 2.2.9, of the object in the Directory Service from which to retrieve the properties.
PathName string `idl:"name:pwcsPathName;string" json:"path_name"`
// cp: MUST be set to the size (in elements) of the arrays aProp and apVar, which
// for this method MUST be one (0x00000001). The arrays aProp and apVar MUST have an
// identical number of elements, and MUST each contain exactly one element.
CreatePartition uint32 `idl:"name:cp" json:"create_partition"`
// aProp: An array of identifiers of properties to retrieve from the object. Each
// element MUST specify a value from the property identifiers table for the object type
// specified in dwObjectType. Each element MUST specify the property identifier for
// the corresponding property value at the same element index in apVar. The array MUST
// contain exactly one element.
Property []uint32 `idl:"name:aProp;size_is:(cp)" json:"property"`
// apVar: MUST be set by the client to an array that holds the property values retrieved
// from the object. Each element MUST be set by the server to the property value for
// the corresponding property identifier at the same element index in aProp. The array
// MUST contain exactly one element.
Var []*mqmq.PropertyVariant `idl:"name:apVar;size_is:(cp)" json:"var"`
// phServerAuth: A PCONTEXT_HANDLE_SERVER_AUTH_TYPE RPC context handle acquired from
// the pphServerAuth parameter in a previous call to S_DSValidateServer (section 3.1.4.2).
// The server MUST use this parameter as a key to locate the GSS security context used
// to compute the signature returned in pbServerSignature. See section 3.1.4.2.
ServerAuth *dscomm.ServerAuthType `idl:"name:phServerAuth" json:"server_auth"`
// pdwServerSignatureSize: A DWORD that contains the maximum length of the server signature
// in bytes to return.
ServerSignatureSize uint32 `idl:"name:pdwServerSignatureSize" json:"server_signature_size"`
}
GetPropertiesExRequest structure represents the S_DSGetPropsEx operation request
func (*GetPropertiesExRequest) MarshalNDR ¶
func (*GetPropertiesExRequest) UnmarshalNDR ¶
type GetPropertiesExResponse ¶
type GetPropertiesExResponse struct {
// apVar: MUST be set by the client to an array that holds the property values retrieved
// from the object. Each element MUST be set by the server to the property value for
// the corresponding property identifier at the same element index in aProp. The array
// MUST contain exactly one element.
Var []*mqmq.PropertyVariant `idl:"name:apVar;size_is:(cp)" json:"var"`
// pbServerSignature: A buffer that contains a signed hash over the returned property
// values. See the pbServerSignature parameter description in section 3.1.4.7.
ServerSignature []byte `idl:"name:pbServerSignature;size_is:(pdwServerSignatureSize)" json:"server_signature"`
// pdwServerSignatureSize: A DWORD that contains the maximum length of the server signature
// in bytes to return.
ServerSignatureSize uint32 `idl:"name:pdwServerSignatureSize" json:"server_signature_size"`
// Return: The S_DSGetPropsEx return value.
Return int32 `idl:"name:Return" json:"return"`
}
GetPropertiesExResponse structure represents the S_DSGetPropsEx operation response
func (*GetPropertiesExResponse) MarshalNDR ¶
func (*GetPropertiesExResponse) UnmarshalNDR ¶
type GetPropertiesGUIDExRequest ¶
type GetPropertiesGUIDExRequest struct {
// dwObjectType: Specifies the type of object for which properties are to be retrieved.
// MUST be set to one of the object types, as specified in section 2.2.8.
ObjectType uint32 `idl:"name:dwObjectType" json:"object_type"`
// pGuid: MUST specify a pointer to the object identifier of the object for which
// properties are to be retrieved.
GUID *dtyp.GUID `idl:"name:pGuid;pointer:unique" json:"guid"`
// cp: MUST be set to the size (in elements) of the arrays aProp and apVar, which
// for this method MUST be one (0x00000001). The arrays aProp and apVar MUST have an
// identical number of elements, and MUST each contain exactly one element.
CreatePartition uint32 `idl:"name:cp" json:"create_partition"`
// aProp: An array of identifiers of properties to retrieve from the object. Each
// element MUST specify a value from the property identifiers for the object type specified
// in dwObjectType. Each element MUST specify the property identifier for the corresponding
// property value at the same element index in apVar. The array MUST contain exactly
// one element.
Property []uint32 `idl:"name:aProp;size_is:(cp)" json:"property"`
// apVar: MUST be set by the client to an array that holds the property values retrieved
// from the object. Each element MUST be set by the server to the property value for
// the corresponding property identifier at the same element index in aProp. The array
// MUST contain exactly one element.
Var []*mqmq.PropertyVariant `idl:"name:apVar;size_is:(cp)" json:"var"`
// phServerAuth: A PCONTEXT_HANDLE_SERVER_AUTH_TYPE RPC context handle acquired from
// the pphServerAuth parameter in a previous call to S_DSValidateServer. The server
// MUST use this parameter as a key to locate the GSS security context used to compute
// the signature returned in pbServerSignature. See section 3.1.4.2.
ServerAuth *dscomm.ServerAuthType `idl:"name:phServerAuth" json:"server_auth"`
// pdwServerSignatureSize: A DWORD that contains the maximum length of the server
// signature in bytes to return.
ServerSignatureSize uint32 `idl:"name:pdwServerSignatureSize" json:"server_signature_size"`
}
GetPropertiesGUIDExRequest structure represents the S_DSGetPropsGuidEx operation request
func (*GetPropertiesGUIDExRequest) MarshalNDR ¶
func (*GetPropertiesGUIDExRequest) UnmarshalNDR ¶
type GetPropertiesGUIDExResponse ¶
type GetPropertiesGUIDExResponse struct {
// apVar: MUST be set by the client to an array that holds the property values retrieved
// from the object. Each element MUST be set by the server to the property value for
// the corresponding property identifier at the same element index in aProp. The array
// MUST contain exactly one element.
Var []*mqmq.PropertyVariant `idl:"name:apVar;size_is:(cp)" json:"var"`
// pbServerSignature: A buffer that contains a signed hash over the returned property
// values. See the pbServerSignature parameter description in section 3.1.4.7.
ServerSignature []byte `idl:"name:pbServerSignature;size_is:(pdwServerSignatureSize)" json:"server_signature"`
// pdwServerSignatureSize: A DWORD that contains the maximum length of the server
// signature in bytes to return.
ServerSignatureSize uint32 `idl:"name:pdwServerSignatureSize" json:"server_signature_size"`
// Return: The S_DSGetPropsGuidEx return value.
Return int32 `idl:"name:Return" json:"return"`
}
GetPropertiesGUIDExResponse structure represents the S_DSGetPropsGuidEx operation response
func (*GetPropertiesGUIDExResponse) MarshalNDR ¶
func (*GetPropertiesGUIDExResponse) UnmarshalNDR ¶
type IsServerGCRequest ¶
type IsServerGCRequest struct {
}
IsServerGCRequest structure represents the S_DSIsServerGC operation request
func (*IsServerGCRequest) MarshalNDR ¶
func (*IsServerGCRequest) UnmarshalNDR ¶
type IsServerGCResponse ¶
type IsServerGCResponse struct {
// Return: The S_DSIsServerGC return value.
Return int32 `idl:"name:Return" json:"return"`
}
IsServerGCResponse structure represents the S_DSIsServerGC operation response
func (*IsServerGCResponse) MarshalNDR ¶
func (*IsServerGCResponse) UnmarshalNDR ¶
type NotifyDeleteRequest ¶
type NotifyDeleteRequest struct {
// Handle: MUST be set by the client to a pointer to an RPC context_handle acquired
// from a previous call to S_DSBeginDeleteNotification. This RPC context handle MUST
// NOT have been used in a previous call to S_DSEndDeleteNotification.
Handle *dscomm.DeleteType `idl:"name:Handle" json:"handle"`
}
NotifyDeleteRequest structure represents the S_DSNotifyDelete operation request
func (*NotifyDeleteRequest) MarshalNDR ¶
func (*NotifyDeleteRequest) UnmarshalNDR ¶
type NotifyDeleteResponse ¶
type NotifyDeleteResponse struct {
// Return: The S_DSNotifyDelete return value.
Return int32 `idl:"name:Return" json:"return"`
}
NotifyDeleteResponse structure represents the S_DSNotifyDelete operation response